@@ -35,7 +35,7 @@
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
-__all__ = ('get_lock', 'release_lock', 'Translation', 'NullTranslation', 'Locale', 'I18N_Error')
+__all__ = ('I18N_Error', 'Locale', 'NullTranslation', 'Translation', 'get_lock', 'release_lock')
 
 from univention.lib.i18n import I18N_Error, Locale, NullTranslation, Translation
 from univention.lib.locking import get_lock, release_lock
