@@ -233,7 +233,7 @@ class UniventionLDAPExtension(six.with_metaclass(ABCMeta)):
         return (p.returncode, object_dn)
 
     def is_applicable_for_current_ucs_version(self, ucr):
-        # type (ConfigRegistry) -> bool
+        # type: (ConfigRegistry) -> bool
         current_ucs_version = "%s-%s" % (ucr.get('version/version'), ucr.get('version/patchlevel'))
         if self.options.ucsversionstart and UCS_Version(current_ucs_version) < UCS_Version(self.options.ucsversionstart):
             return False
@@ -502,7 +502,7 @@ class UniventionLDAPExtension(six.with_metaclass(ABCMeta)):
         self.options = options
         self.udm_passthrough_options = udm_passthrough_options
 
-        rc, object_dn, stdout = self.udm_find_object_dn()
+        _rc, object_dn, stdout = self.udm_find_object_dn()
         if not object_dn:
             print("ERROR: Object not found in UDM.", file=sys.stderr)
             return
@@ -590,7 +590,7 @@ class UniventionLDAPSchema(UniventionLDAPExtensionWithListenerHandler):
     basedir = '/var/lib/univention-ldap/local-schema'
 
     def is_applicable_for_current_ucs_version(self, ucr):
-        # type (ConfigRegistry) -> bool
+        # type: (ConfigRegistry) -> bool
         return True
 
     def handler(self, dn, new, old, name=""):
@@ -1060,11 +1060,11 @@ class UniventionDataExtension(UniventionLDAPExtension):
     filesuffix = ''
 
     def is_local_active(self):
+        # type: () -> Tuple[int, Optional[str]]
         """
         There is nothing to activate for a data extension,
         just pretend that everything is fine.
         """
-        # type: () -> Tuple[int, Optional[str]]
         return (0, "foo")
 
     def wait_for_activation(self, timeout=180):
@@ -1445,7 +1445,7 @@ def ucs_registerLDAPExtension():
         help="File containing LDAP bindpwd", metavar="<filename>")
     parser.add_option_group(auth_options)
 
-    opts, args = parser.parse_args()
+    opts, _args = parser.parse_args()
     if len(opts.udm_module) > 1:
         parser.error('--udm_module option can be given once only.')
     if not opts.packagename:
@@ -1583,7 +1583,7 @@ def ucs_unregisterLDAPExtension():
         type="existing_filename",
         help="File containing LDAP bindpwd", metavar="<filename>")
     parser.add_option_group(auth_options)
-    opts, args = parser.parse_args()
+    opts, _args = parser.parse_args()
 
     ucr = ConfigRegistry()
     ucr.load()
