@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2023 Univention GmbH
+# Copyright 2017-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -61,7 +61,7 @@ from univention.config_registry import ConfigRegistry
 
 
 Morsel._reserved['samesite'] = 'SameSite'
-_T = TypeVar("_T")
+_T = TypeVar("_T")  # noqa: PYI018
 
 ucr = ConfigRegistry()
 ucr.load()
