@@ -31,10 +31,18 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+import sys
+
 import pytest
 from univentionunittests import import_module
 
 
+if sys.version_info[0] == 2:
+    from mock import MagicMock
+else:
+    from unittest.mock import MagicMock
+
+
 def pytest_addoption(parser):
     parser.addoption("--installed-lib", action="store_true", help="Test against installed Python lib installation (not src)")
 
@@ -71,6 +79,12 @@ def locking(request):
 
 @pytest.fixture(scope='session')
 def misc(request):
+    sys.modules['univention.uldap'] = MagicMock()
+    if sys.version_info[0] == 2:
+        sys.modules['univention.lib'] = MagicMock()
+        sys.modules['univention.lib.ucs'] = MagicMock()
+    else:
+        import_lib_module(request, 'ucs')
     return import_lib_module(request, 'misc')
 
 
